NOT FINISHED YET!!! My first try to get a self built fully working Quadrocopter based on an mbed, a self built frame and some other more or less cheap parts.

Dependencies:   mbed MODI2C

Revision:
37:34917f7c10ae
Parent:
34:3aa1cbcde59d
Child:
38:ff95fd524c9e
--- a/Mixer/Mixer.cpp	Wed Jun 12 10:26:18 2013 +0000
+++ b/Mixer/Mixer.cpp	Wed Jun 12 16:42:32 2013 +0000
@@ -33,6 +33,8 @@
             Motor_speed[i] += mix_table[Configuration][i][j] * controller_value[j];
     }
     
-    for(int i = 0; i < 4; i++) // make sure no motor stands still
+    for(int i = 0; i < 4; i++) { // make sure no motor stands still or gets a higher speed than 1000
         Motor_speed[i] = Motor_speed[i] > 150 ? Motor_speed[i] : 150;
+        Motor_speed[i] = Motor_speed[i] <= 1000 ? Motor_speed[i] : 1000;
+    }
 }
\ No newline at end of file